<?php

/*  Copyright 2011 Simon Wheatley

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/

// require_once( 'class-SMS.php' );

/**
 * Send SMS messages using an Email to SMS gateway.
 * 
 * @package Mediaburst Email 2 SMS plugin
 * @author Simon Wheatley
 **/
class Transport_Email2SMS {

	/**
	 * The current message to send.
	 *
	 * @var string
	 **/
	protected $message;
	
	/**
	 * Set the SMS message string.
	 *
	 * @param string $message The message to send 
	 * @return void
	 * @author Simon Wheatley
	 **/
	public function set_message( $message ) {
		$this->message = $message;
	}
	
	/**
	 * Send current SMS message to all subscribers.
	 *
	 * @return void
	 * @author Simon Wheatley
	 **/
	public function send_to_all() {
		$page = 1;
		$page_size = 30; // Sending emails to 30 people at once seems OK?
		while ( $subscribers = Email2SMS_Subscribers::get_paged( $page, $page_size, true ) ) {
			$page++;
			$subscriber_emails = array();
			foreach( $subscribers as $s ) {
				// You can define a MBE2S_TEST_EMAIL for testing, allowing you
				// to direct the email most anywhere you want. An example of a test
				// mail, taking advantage of GMail's ability to route anything like
				// yourmail+whatever@yourdomain.com to your inbox might be:
				// define( 'MBE2S_TEST_EMAIL', 'yourmail+{number}-{domain}@yourdomain.com' );
				if ( defined( 'MBE2S_TEST_EMAIL' ) && MBE2S_TEST_EMAIL ) {
					$search = array( '{number}', '{domain}'	);
					$replace = array( $s->subscriber_number, $s->provider_domain );
					$subscriber_emails[] = str_replace( $search, $replace, MBE2S_TEST_EMAIL );
				} else {
					$subscriber_emails[] = "{$s->provider_prefix}{$s->subscriber_number}@{$s->provider_domain}";
				}
			}
			$this->send_to_emails( $subscriber_emails );
		}
	}
	
	/**
	 * Send current SMS message to a particular number.
	 *
	 * @param array $numbers The numbers to send it to
	 * @return void
	 * @author Simon Wheatley
	 **/
	protected function send_to_emails( $emails ) {
		$to = join( ',', $emails );
		$subject = '';
		wp_mail( $to, $subject, $this->message );
	}

} // END Email2SMS class 

?>