<?php

/*  Copyright 2010 Simon Wheatley

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/

require_once( 'class-Widget.php' );

/**
 * new WordPress Widget format
 * Wordpress 2.8 and above
 * @see http://codex.wordpress.org/Widgets_API#Developing_Widgets
 */
class MBE2S_Subscribe_Widget extends MBE2S_Widget {
	
	/**
	 * Store any form errors.
	 *
	 * @var array
	 **/
	protected $errors;
	
	/**
	 * The version of this widget
	 *
	 * @var int
	 **/
	protected $version;
	
	function __construct() {
		$widget_ops = array( 
			'classname' => 'mbe2s-subscribe', 
			'description' => __( 'Provide a way for users to subscribe to the your SMS updates.', 'mbe2s' )
		);
		$this->WP_Widget( 'mbe2s-subscribe', __( 'Mediaburst: SMS Subscribe', 'mbe2s' ), $widget_ops );
		// Enqueue our JS, when not in the admin area
		$this->enqueue();
		$this->version = 2;
	}

	function widget( $args, $instance ) {
		extract( $args );
		extract( $instance, EXTR_SKIP );

		$title = apply_filters( 'widget_title', $title );

		// Get all active providers
		$providers = Email2SMS_Providers::get_all();

?>
	<?php echo $before_widget; ?>
	<?php if ( $title ) : ?>
		<?php echo $before_title . $title . $after_title; ?>
	<?php endif; ?>
	
	<?php if ( $intro ) : ?>
		<p><?php echo esc_html( $intro ); ?></p>
	<?php endif; ?>

	<form action="<?php echo esc_attr( admin_url( 'admin-ajax.php' ) ); ?>" method="post" class="mbe2s-subscribe">
		<!-- <input type="text" name="mbe2s-subscribe" value="<?php echo esc_attr( $widget_id ); ?>" /> -->
		<input type="hidden" name="action" value="mbe2s_subscribe" id="action">
	 	<p class="mbe2s-provider">
			<label for="<?php echo esc_attr( $widget_id ); ?>-provider">
				<span><?php _e( 'Select a mobile provider', 'mbe2s' ); ?></span>
				<select name="provider" id="<?php echo esc_attr( $widget_id ); ?>-provider">
					<option value=""><?php _e( '– select –', 'mbe2s' ); ?></option>
					<?php $country = false; foreach ( $providers as $provider ) : ?>
					<?php if ( $country && $country != $provider->provider_country ) : ?>
					    </optgroup>
					<?php endif; ?>
					<?php if ( $country != $provider->provider_country ) : ?>
					    <optgroup class="mbe2s-<?php echo esc_attr( sanitize_title( $provider->provider_country ) ); ?>" label="<?php echo esc_attr( $provider->provider_country ); ?>">
					<?php endif; ?>
					<option value="<?php echo esc_attr( $provider->provider_id ); ?>"><?php echo esc_html( $provider->provider_name ); ?></option>
					<?php $country = $provider->provider_country; endforeach; ?>
					<?php if ( $country != $provider->provider_country ) : ?>
					    </optgroup>
					<?php endif; ?>
				    <optgroup label="<?php _e( 'Other', 'mbe2s' ); ?>">
						<option value="none"><?php _e( 'Provider not listed', 'mbe2s' ); ?></option>
					</optgroup>
				</select>
			</label>
	 	</p>
		<p class="mbe2s-number">
			<label for="<?php echo esc_attr( $widget_id ); ?>-number">
				<span><?php _e( 'Enter your mobile number', 'mbe2s' ); ?></span>
				<input type="text" name="number" value="" id="<?php echo esc_attr( $widget_id ); ?>number">
			</label>
		</p>
		<p class="mbe2s-subscribe">
			<input type="submit" name="some_name" value="<?php echo esc_attr( __( 'Subscribe', 'mbe2s' ) ); ?>" />
			|
			<a href="<?php echo esc_attr( add_query_arg( array( 'mbe2s-unsubscribe' => 1 ), home_url() ) ); ?>"><?php _e( 'unsubscribe', 'mbe2s' ); ?></a>
		</p>
 	</form>
	<?php if ( $show_link ) : ?>
		<p class="mbe2s-small"><a href="http://www.mediaburst.co.uk/wordpress/wordpress-sms-plugin/"><?php _e( 'SMS by mediaburst', 'mbe2s' ); ?></a></p>
	<?php endif; ?>

	<?php echo $after_widget; ?>
<?php

	}

	function update( $new_instance, $old_instance ) {
		// update logic goes here
		$updated_instance = $new_instance;
		return $updated_instance;
	}

	function form( $instance ) {
		extract( $instance, EXTR_SKIP );
		// If the instance is empty, then this is a new widget
		// and we can default the Mediaburst backlink to "on".
		if ( empty( $instance ) )
			$show_link = true;
		if ( empty( $title ) )
			$title = __( 'Subscribe to SMS Updates', 'mbe2s' );
		$this->input_text( __( 'Title', 'mbe2s' ), 'title', $title );
		$this->input_text( __( 'Intro', 'mbe2s' ), 'intro', $intro, __( 'Any intro text will be put at the top of your subscription form.', 'mbe2s' ) );
		$note = __( 'We\'ve included a link on the widget, "SMS by mediaburst". It\'s quite discreet and you can turn it off at any time by deselecting this option; but we do provide this plugin for free and when you leave it on we get a little bit of SEO goodness, so if you can see your way to leave it on it would make us very happy. Thanks.', 'mbe2s' );
		$this->input_checkbox( __( 'Link to Mediaburst', 'mbe2s' ), 'show_link', $show_link, $note );
	}

	/**
	 * Enqueues anything we need enqueuing.
	 * 
	 * You can override this if you want to customise 
	 * the scripts and/or CSS used for this widget.
	 *
	 * @return void
	 * @author Simon Wheatley
	 **/
	protected function enqueue() {
		if ( is_admin() )
			return;
		$suffix = defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ? '.dev' : '';
		wp_enqueue_script( 'mbe2s-widget', mbe2s_url( "/js/widget{$suffix}.js" ), array( 'jquery' ), MBE2S_VERSION );
		$localized = array( 
			'country_label' => __( 'Select a country', 'mbe2s' ), 
			'pick_country' => __( '– select –', 'mbe2s' ),
			'select_country_provider' => __( 'Now select a provider', 'mbe2s' ),
			'error_number' => __( 'Please enter a mobile phone number.', 'mbe2s' ), // See also non-JS response
			'error_provider' => __( 'Please select a provider.', 'mbe2s' ), // See also non-JS response
		);
		wp_localize_script( 'mbe2s-widget', 'mbe2s_widget', $localized );
		wp_enqueue_style( 'mbe2s-widget', mbe2s_url( "/css/widget{$suffix}.css" ), null, MBE2S_VERSION );
	}

}

add_action( 'widgets_init', create_function( '', "register_widget('MBE2S_Subscribe_Widget');" ) );

?>