<?php

/*  Copyright 2011 Simon Wheatley

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/

/**
 * Utility: provides the URL to something in this plugin dir.
 *
 * @param string $path The path within this plugin dir 
 * @return string The absolute URL
 * @author Simon Wheatley
 **/
function mbe2s_url( $path ) {
	$folder = rtrim( basename( dirname( __FILE__ ) ), '/' );
	$dir = trailingslashit( WP_PLUGIN_DIR ) . $folder;
	$url = plugins_url( $folder );
	return $url . $path;
}

/**
 * Display the pagination. Cribbed from class-wp-list-table-php.
 *
 * Args (array):
 * * total_items – The total number of items available
 * * current – The current page number
 * * total_pages – The total number of available pages
 * * which – Either "top" or "bottom" depending on the position of this set of pagination ctrls
 * 
 * @since 3.1.0
 *
 * @param array $args The pagination args (see above)
 * @return string The HTML for the pagination
 * @author WordPress
 */
function mbe2s_pagination( $args ) {

	extract( $args );

	$output = '<span class="displaying-num">' . sprintf( _n( '1 item', '%s items', $total_items ), number_format_i18n( $total_items ) ) . '</span>';

	$current_url = ( is_ssl() ? 'https://' : 'http://' ) . $_SERVER['HTTP_HOST'] . $_SERVER['REQUEST_URI'];

	$current_url = remove_query_arg( array( 'hotkeys_highlight_last', 'hotkeys_highlight_first' ), $current_url );

	$page_links = array();

	$disable_first = $disable_last = '';
	if ( $current == 1 )
		$disable_first = ' disabled';
	if ( $current == $total_pages )
		$disable_last = ' disabled';

	$page_links[] = sprintf( "<a class='%s' title='%s' href='%s'>%s</a>",
		'first-page' . $disable_first,
		esc_attr__( 'Go to the first page' ),
		esc_url( remove_query_arg( 'paged', $current_url ) ),
		'&laquo;'
	);

	$page_links[] = sprintf( "<a class='%s' title='%s' href='%s'>%s</a>",
		'prev-page' . $disable_first,
		esc_attr__( 'Go to the previous page' ),
		esc_url( add_query_arg( 'paged', max( 1, $current-1 ), $current_url ) ),
		'&lsaquo;'
	);

	if ( 'bottom' == $which )
		$html_current_page = $current;
	else
		$html_current_page = sprintf( "<input class='current-page' title='%s' type='text' name='%s' value='%s' size='%d' />",
			esc_attr__( 'Current page' ),
			esc_attr( 'paged' ),
			$current,
			strlen( $total_pages )
		);

	$html_total_pages = sprintf( "<span class='total-pages'>%s</span>", number_format_i18n( $total_pages ) );
	$page_links[] = '<span class="paging-input">' . sprintf( _x( '%1$s of %2$s', 'paging' ), $html_current_page, $html_total_pages ) . '</span>';

	$page_links[] = sprintf( "<a class='%s' title='%s' href='%s'>%s</a>",
		'next-page' . $disable_last,
		esc_attr__( 'Go to the next page' ),
		esc_url( add_query_arg( 'paged', min( $total_pages, $current+1 ), $current_url ) ),
		'&rsaquo;'
	);

	$page_links[] = sprintf( "<a class='%s' title='%s' href='%s'>%s</a>",
		'last-page' . $disable_last,
		esc_attr__( 'Go to the last page' ),
		esc_url( add_query_arg( 'paged', $total_pages, $current_url ) ),
		'&raquo;'
	);

	$output .= "\n<span class='pagination-links'>" . join( "\n", $page_links ) . '</span>';

	if ( $total_pages )
		$page_class = $total_pages < 2 ? ' one-page' : '';
	else
		$page_class = ' no-pages';

	return "<div class='tablenav-pages{$page_class}'>$output</div>";
}

/**
 * The database character collate.
 *
 * @return string The database character collate.
 * @author Simon Wheatley
 **/
function mbe2s_db_charset_collate() {
	global $wpdb;

	$charset_collate = '';

	if ( ! empty($wpdb->charset) )
		$charset_collate = "DEFAULT CHARACTER SET $wpdb->charset";
	if ( ! empty($wpdb->collate) )
		$charset_collate .= " COLLATE $wpdb->collate";
		
	return $charset_collate;
}

?>